AlertInfo class
Data class for the alert stream.
Constructors
- AlertInfo(AlertEvent event, String message)
- Data class for the alert stream.
Properties
- event → AlertEvent
-
The event that caused the alert to happen.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message to show to the user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited