alertDialogBuilder property
If specified, this will be used to create the alert dialog rather than the default.
Implementation
final Widget Function(BuildContext context, AlertInfo info)?
alertDialogBuilder;
If specified, this will be used to create the alert dialog rather than the default.
final Widget Function(BuildContext context, AlertInfo info)?
alertDialogBuilder;