AlertBloc class
Needs to be added up the Widget tree and have the stream be listened to.
YOu can look at AlertWatcher for an automatic implementation of this.
Constructors
Properties
-
blocUpdated
↔ List<
void Function()> -
Add functions to this to be ran when the
Blocis updated.getter/setter pairinherited - eventChannel → BlocEventChannel
-
Events that the UI fire to affect this
Blocare received through here.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
AlertInfo> -
The stream for the alerts that occur.
no setter
Methods
-
dispose(
) → void -
Disposes this value to save memory. Implementations should be idempotent.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateBloc(
) → void -
Signal that this
Blochas been updated. This will call all listeners added toblocUpdated.inherited -
updateBlocOnChange(
{required dynamic change(), required List tracker()}) → void -
Updates the
Blocafter callingchangeif the value returned bytrackerchanges.inherited -
updateBlocOnFutureChange(
{required Future change(), required List tracker()}) → Future< void> -
Updates the
Blocafter callingchangeif the value returned bytrackerchanges.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited